/*!
 * @license
 * 
 * candle.js v0.3.0
 *  https://bitbucket.org/sabo2/candle
 * 
 * This script is referencing following library.
 *  uuCanvas.js (version 1.0)
 *  http://code.google.com/p/uupaa-js-spinoff/
 * 
 * Copyright 2011-2015 sabo2
 * 
 * This script is released under the MIT license. Please see below.
 *  http://www.opensource.org/licenses/mit-license.php
 * 
 * Date: 2015-02-15
 */
// intro.js

(function(){

// 多重定義防止
if(!!window.Candle){ return;}

// candle.core.js
/* exported Candle, _doc, _2PI */

/* ------------- */
/*   variables   */
/* ------------- */
var _doc = document,
	_2PI = 2*Math.PI,
	_color = [],
	_css = [];

/* ---------- */
/*   arrays   */
/* ---------- */
var _hex = (function(){
	var tbl = [];
	for(var r=256;r<512;r++){ tbl[r-256]=r.toString(16).substr(1);}
	return tbl;
})();

/* ---------------------- */
/*   Candleオブジェクト   */
/* ---------------------- */
var Candle = {
	version : '0.3.0',
	
	/* wrapper classes */
	wrapper : {},
	addWrapper : function(classname, proto){
		classname = classname.replace(/\s+/g,'');
		var colon = classname.indexOf(':'), basename = '';
		if(colon>=0){
			basename  = classname.substr(colon+1);
			classname = classname.substr(0,colon);
		}

		var NewClass = function(){ if(!!this.initialize){ this.initialize.apply(this,arguments);}};
		var name;
		if(!!basename && !!this.wrapper[basename]){
			var BaseClass = this.wrapper[basename];
			for(name in BaseClass.prototype){ NewClass.prototype[name] = BaseClass.prototype[name];}
		}
		for(name in proto){ NewClass.prototype[name] = proto[name];}
		NewClass.prototype.constructor = NewClass;
		var rel = {body:NewClass, name:classname, base:basename};
		this.wrapper[rel.name] = rel.body;
	},

	/* TypeList class */
	_order : [],
	enable : {},
	addTypes : function(type){
		this._order.push(type);
		this.enable[type] = true;
		if(!this.current){ this.current=type;}
	},

	TypeList : function(type){
		for(var i=0;i<Candle._order.length;i++){
			this[Candle._order[i]]=(Candle._order[i]===type);
		}
	},

	/* Selected & Enable types */
	current : '',
	select : function(type){
		if(!this.enable[type]){ return false;}
		this.current = type;
		return true;
	},

	/* externs */
	ME     : null,
	initME : function(){
		var me = _doc.createElement('div');
		me.style.display  = 'inline';
		me.style.position = 'absolute';
		me.style.left     = '-9000px';
		me.innerHTML = '';
		_doc.body.appendChild(me);

		this.ME = me;
	},

	/* color parser */
	color : _color,
	parse : function(rgbstr){
		if(!_color[rgbstr]){
			if(rgbstr.substr(0,4)==='rgb('){
				var m = rgbstr.match(/\d+/g);
				_color[rgbstr] = ["#",_hex[m[0]],_hex[m[1]],_hex[m[2]]].join('');
			}
			else{ _color[rgbstr] = rgbstr;}
		}
		return _color[rgbstr];
	},

	/* DOM datas */
	getRectSize : function(el){
		return { width :(el.offsetWidth  || el.clientWidth),
				 height:(el.offsetHeight || el.clientHeight)};
	},

	/* functions */
	_counter : -1,
	getcanvasid : function(){
		this._counter++;
		return "_candle_"+this._counter;
	},

	initAllElements : function(){
		var elements = _doc.getElementsByTagName('candle');
		for(var i=0;i<elements.length;i++){ this.start(elements[i]);}
	},
	start : function(element, type, initCallBack){
		initCallBack = initCallBack || function(){};
		if(!this.ME){ this.initME();}

		if(typeof element === "string"){ element = document.getElementById(element);}
		var context;
		if(!element.candleEnable){
			var choice = type;
			if(!this.enable[choice]){ choice=this.current;}
			if(!this.enable[choice]){ return;}

			context = new this.wrapper[choice](element);
		}
		else{
			context = element.parentNode.getContext('2d');
		}

		initCallBack(context);
	},

	/* initialize functions */
	onload : function(){
		this.createCSS();
		this.initAllElements();
	},

	sheet : null,
	createCSS : function(){
		if(!!this.sheet){ return;}
		var _head = _doc.getElementsByTagName('head')[0];
		if(!!_head){
			var style = _doc.createElement('style');
			style.setAttribute('type', "text/css");
			_head.appendChild(style);
		}
		else{ _doc.write("<style></style>");}
		this.sheet = _doc.styleSheets[_doc.styleSheets.length - 1];
		for(var i=0;i<_css.length;i++){ this.addCSS(_css[i][0],_css[i][1]);}
		_css=[];
	},
	addCSS : function(sel,rule){
		if(!!this.sheet){
			var s = this.sheet;
			if(!!s.insertRule){ s.insertRule(sel+'{'+rule+'}',s.cssRules.length);}
			else if(!!s.addRule){ s.addRule(sel,rule,-1);}
		}
		else{ _css.push(sel,rule);}
	}
};

// 初期化関数設定 
if(!!window.addEventListener){ window.addEventListener("load",function(){ Candle.onload();},false);}
else if(!!window.attachEvent){ window.attachEvent("onload",function(){ Candle.onload();});}

// IE用ハック
_doc.createElement('candle');

// CSS設定 
Candle.createCSS();

// extern
window.Candle = Candle;

// candle.base.js
/* global Candle:false, _doc:false, _2PI:false */
 
/* ------------------- */
/*  WrapperBaseクラス  */
/* ------------------- */
Candle.addWrapper('wrapperbase',{
	initialize : function(parent){
		// canvasに存在するプロパティ＆デフォルト値
		this.fillStyle    = 'black';
		this.strokeStyle  = 'black';
		this.lineWidth    = 1;
		this.font         = '14px system';
		this.textAlign    = 'center';
		this.textBaseline = 'middle';
		this.canvas = parent;	// 親エレメントとなるdivエレメント

		// variables for internal
		this.canvasid = Candle.getcanvasid();
		this.child    = null;	// 親エレメントの直下にあるエレメント

		// Layer additional
		this.currentLayerId = '_empty';
		this.isedgearray    = {_empty:false};
		this.isedge         = false;

		this.setParent();
		this.initElement();
		this.initFunction();
		this.initLayer();

		var self = this;
		this.canvas.getContext = function(type){ return self;};
		this.canvas.candleEnable = true;
	},

	/* Initialize functions */
	setParent : function(){
		this.canvas.style.overflow = 'hidden';
	},
	initElement : function(){},
	initFunction : function(){
		/* 未サポート用 */
		this.canvas.toDataURL = function(type)   { return null;};
		this.canvas.toBlob    = function(f, type){ return null;};
	},
	initLayer : function(){
		this.setLayer();
	},

	/* layer functions */
	setLayer : function(layerid, option){
		this.currentLayerId = (!!layerid ? layerid : '_empty');
		this.setLayerEdge();
		this.setEdgeStyle();
		
		option = option || {};
		if(option.rendering){ this.setRendering(option.rendering);}
	},
	setLayerEdge : function(){
		if(this.isedgearray[this.currentLayerId] !== void 0)
			{ this.isedge = this.isedgearray[this.currentLayerId];}
		else
			{ this.isedge = this.isedgearray['_empty'];}
	},
	setEdgeStyle : function(){},

	/* property functions */
	setRendering : function(render){
		this.isedge = this.isedgearray[this.currentLayerId] = (render==='crispEdges');
		this.setEdgeStyle();
	},

	/* Canvas API functions (rect) */
	rectcenter       : function(cx,cy,bw,bh){ this.rect      (cx-bw,cy-bh,2*bw,2*bh);},
	fillRectCenter   : function(cx,cy,bw,bh){ this.fillRect  (cx-bw,cy-bh,2*bw,2*bh);},
	strokeRectCenter : function(cx,cy,bw,bh){ this.strokeRect(cx-bw,cy-bh,2*bw,2*bh);},
	shapeRectCenter  : function(cx,cy,bw,bh){ this.shapeRect (cx-bw,cy-bh,2*bw,2*bh);},

	/* VectorID Functions */
	vshow : function(){},
	vhide : function(){},
	vdel  : function(){}
});

/* ----------------------- */
/*   VectorContextクラス   */
/* ----------------------- */
Candle.addWrapper('vector:wrapperbase',{

	initialize : function(parent){
		// 外部から変更される追加プロパティ
		this.vid      = '';
		this.elements = {};
		this._textcache = {};

		// variables for internal
		this.zidx = 1;
		this.zidx_array = {};
		this.target = null;	// エレメントの追加対象となるオブジェクト

		// 描画中path
		this.cpath    = [];
		this.lastpath = '';
		this.freezepath = false;

		Candle.wrapper.wrapperbase.prototype.initialize.call(this, parent);
	},

	/* additional functions (for initialize) */
	initLayer : function(){
		this.setLayer();

		var rect = Candle.getRectSize(this.canvas);
		this.rect(0,0,rect.width,rect.height);
		this.addVectorElement(false,false);
	},

	initTarget : function(){
		this.target = _doc.getElementById(this.canvasid);
	},
	clear : function(){
		var top = this.canvas.firstChild, el = top.firstChild;
		while(!!el){ top.removeChild(el); el=top.firstChild;}
		this.resetElement();
	},
	resetElement : function(){
		this.vid = '';
		this.elements = {};
		this.initTarget();
		this.zidx = 1;
		this.zidx_array = {};
		this.setLayer();
		this._textcache = {};
	},

	/* layer functions */
	setLayer : function(layerid, option){
		this.vid = '';
		if(!!layerid){
			var lid = [this.canvasid,"layer",layerid].join('_');
			var layer = _doc.getElementById(lid);
			if(!layer){ layer = this.createLayer(lid);}

			if(!this.zidx_array[layerid]){
				this.zidx++;
				this.zidx_array[layerid] = layer.style.zIndex = this.zidx;
			}
			this.target = layer;
		}
		else{
			this.target = this.child;
		}
		Candle.wrapper.wrapperbase.prototype.setLayer.call(this, layerid, option);
		this.freezepath = (!!option && option.freeze);
	},
	createLayer : function(lid){ return null;},

	/* property functions */
	changeSize : function(width,height){
		this.canvas.style.width  = width + 'px';
		this.canvas.style.height = height + 'px';

		this.changeChildSize(this.canvas.firstChild,width,height);
	},
	changeChildSize : function(child,width,height){},

	/* Canvas API functions (for transform) */
	translate : function(left,top){},

	/* Canvas API functions (for path) */
	beginPath : function(){
		this.cpath = [];
		this.lastpath = '';
	},
	closePath : function(){
		this.cpath.push(this.PATH_CLOSE);
		this.lastpath = this.PATH_CLOSE;
	},

	moveTo : function(x,y){
		this.cpath.push(this.PATH_MOVE,x,y);
		this.lastpath = this.PATH_MOVE;
	},
	lineTo : function(x,y){
		if(this.lastpath!==this.PATH_LINE){ this.cpath.push(this.PATH_LINE);}
		this.cpath.push(x,y);
		this.lastpath = this.PATH_LINE;
	},
	rect : function(x,y,w,h){
		this.cpath.push(this.PATH_MOVE,x,y,this.PATH_LINE,(x+w),y,(x+w),(y+h),x,(y+h),this.PATH_CLOSE);
		this.lastpath = this.PATH_CLOSE;
	},
	arc : function(cx,cy,r,startRad,endRad,antiClockWise){
		var sx,sy,ex,ey;
		if(endRad-startRad>=_2PI){ sx=cx+r; sy=cy; ex=cx+r; ey=cy;}
		else{
			sx = cx + r*Math.cos(startRad); sy = cy + r*Math.sin(startRad);
			ex = cx + r*Math.cos(endRad);   ey = cy + r*Math.sin(endRad);
		}
		if(endRad-startRad>=_2PI){ sy+=0.125;}
		var unknownflag = (startRad>endRad)^(Math.abs(endRad-startRad)>Math.PI);
		var islong = ((antiClockWise^unknownflag)?1:0), sweep = ((islong===0^unknownflag)?1:0);
		this.cpath.push(this.PATH_MOVE,sx,sy,this.PATH_ARCTO,r,r,0,islong,sweep,ex,ey);
		this.lastpath = this.PATH_ARCTO;
	},

	/* Canvas API functions (for drawing) */
	fill   : function(){ this.addVectorElement(true,false);},
	stroke : function(){ this.addVectorElement(false,true);},
	shape  : function(){ this.addVectorElement(true,true);}, /* extension */

	/* Canvas API functions (rect) */
	fillRect   : function(x,y,w,h){
		var stack = this.cpath;
		this.cpath = [];
		this.rect(x,y,w,h);
		this.addVectorElement(true,false);
		this.cpath = stack;
	},
	strokeRect : function(x,y,w,h){
		var stack = this.cpath;
		this.cpath = [];
		this.rect(x,y,w,h);
		this.addVectorElement(false,true);
		this.cpath = stack;
	},
	shapeRect  : function(x,y,w,h){
		var stack = this.cpath;
		this.cpath = [];
		this.rect(x,y,w,h);
		this.addVectorElement(true,true);
		this.cpath = stack;
	},

	/* extended functions */
	setLinePath : function(){
		var _args=arguments, _len=_args.length, len=_len-((_len|1)?1:2), a=[];
		for(var i=0;i<len;i+=2){ a[i>>1] = [_args[i],_args[i+1]];}
		this.beginPath();
		this.setLinePath_com.call(this,a);
		if(_args[_len-1]){ this.cpath.push(this.PATH_CLOSE);}
	},
	setOffsetLinePath : function(){
		var _args=arguments, _len=_args.length, len=_len-((_len|1)?1:2), a=[];
		for(var i=0;i<len-2;i+=2){ a[i>>1] = [_args[i+2]+_args[0], _args[i+3]+_args[1]];}
		this.beginPath();
		this.setLinePath_com.call(this,a);
		if(_args[_len-1]){ this.cpath.push(this.PATH_CLOSE);}
	},
	setLinePath_com : function(array){
		for(var i=0,len=array.length;i<len;i++){
			this.cpath.push(i===0 ? this.PATH_MOVE : this.PATH_LINE);
			this.cpath.push(array[i][0],array[i][1]);
		}
	},
	setDashSize : function(obj, sizes){},

	strokeLine : function(x1,y1,x2,y2){
		var stack = this.cpath;
		this.cpath = [this.PATH_MOVE,x1,y1,this.PATH_LINE,x2,y2];
		this.addVectorElement(false,true);
		this.cpath = stack;
	},
	strokeDashedLine : function(x1,y1,x2,y2,sizes){
		var stack = this.cpath;
		this.cpath = [this.PATH_MOVE,x1,y1,this.PATH_LINE,x2,y2];
		var obj = this.addVectorElement(false,true);
		this.setDashSize(obj, sizes);
		this.cpath = stack;
	},
	strokeCross : function(cx,cy,l){
		var stack = this.cpath;
		this.cpath = [this.PATH_MOVE,(cx-l),(cy-l),this.PATH_LINE,(cx+l),(cy+l),
					  this.PATH_MOVE,(cx-l),(cy+l),this.PATH_LINE,(cx+l),(cy-l)];
		this.addVectorElement(false,true);
		this.cpath = stack;
	},

	/* extended functions (circle) */
	fillCircle : function(cx,cy,r){
		var stack = this.cpath;
		this.cpath = [];
		this.arc(cx,cy,r,0,_2PI,false);
		this.cpath.push(this.PATH_CLOSE);
		this.addVectorElement(true,false);
		this.cpath = stack;
	},
	strokeCircle : function(cx,cy,r){
		var stack = this.cpath;
		this.cpath = [];
		this.arc(cx,cy,r,0,_2PI,false);
		this.cpath.push(this.PATH_CLOSE);
		this.addVectorElement(false,true);
		this.cpath = stack;
	},
	shapeCircle : function(cx,cy,r){
		var stack = this.cpath;
		this.cpath = [];
		this.arc(cx,cy,r,0,_2PI,false);
		this.cpath.push(this.PATH_CLOSE);
		this.addVectorElement(true,true);
		this.cpath = stack;
	},

	/* Canvas API functions (for text) */
	fillText : function(text,x,y){
		var el = (!!this.vid ? this.elements[this.vid] : null);
		if(!!text && !!this.fillStyle && this.fillStyle!=="none"){
			var el2 = this.fillText_main(el,text,x,y);
			if(!el && !!this.vid){ this.elements[this.vid] = el2;}
		}
		else if(!!el){ this.hide(el);}
		this.vid = '';
	},
	fillText_main : function(text,x,y){},

	/* Canvas API functions (for image) */
	drawImage : function(image,sx,sy,sw,sh,dx,dy,dw,dh){
		var el = (!!this.vid ? this.elements[this.vid] : null);
		if(!!image){
			if(sw===(void 0)){ sw=image.width; sh=image.height;}
			if(dx===(void 0)){ dx=sx; sx=0; dy=sy; sy=0; dw=sw; dh=sh;}
			
			var el2 = this.drawImage_main(el,image,sx,sy,sw,sh,dx,dy,dw,dh);
			if(!el && !!this.vid){ this.elements[this.vid] = el2;}
		}
		else if(!!el){ this.hide(el);}
		this.vid = '';
	},
	drawImage_main : function(el,image,sx,sy,sw,sh,dx,dy,dw,dh){},

	/* internal functions */
	addVectorElement : function(isfill,isstroke){
		isfill   = isfill   && !!this.fillStyle   && (this.fillStyle  !=="none");
		isstroke = isstroke && !!this.strokeStyle && (this.strokeStyle!=="none");
		var el = (!!this.vid ? this.elements[this.vid] : null), el2 = null;
		if(isfill || isstroke){
			el2 = this.addVectorElement_main(el,isfill,isstroke);
			if(!el && !!this.vid){ this.elements[this.vid] = el2;}
		}
		else if(!!el){ this.hide(el);}
		this.vid = '';
		return el2;
	},
	addVectorElement_main : function(el,isfill,isstroke){},

	/* VectorID Functions */
	vhide : function(vids){
		var el = this.elements[this.vid];
		if(!!el){ this.hide(el);}
	},
	vdel  : function(vids){
		var el = this.elements[this.vid];
		if(!!el){
			this.target.removeChild(el);
			delete this.elements[this.vid];
		}
	},
	
	show : function(el){ el.removeAttribute('display');},
	hide : function(el){ el.setAttribute('display', 'none');}
});

// candle.svg.js
/* global Candle:false, _doc:false */

(function(){

/* ------------------- */
/*   SVG描画可能条件   */
/* ------------------- */
var SVGNS   = Candle.SVGNS   = "http://www.w3.org/2000/svg",
	XLINKNS = Candle.XLINKNS = "http://www.w3.org/1999/xlink";
if(!document.createElementNS || !document.createElementNS(SVGNS, 'svg').suspendRedraw){ return;}

function newEL(tag){ return _doc.createElementNS(SVGNS, tag);}

/* ------------------------------------------- */
/*   VectorContext(SVG)クラス用const文字列集   */
/* ------------------------------------------- */
var S_PATH_MOVE   = 'M',
	S_PATH_LINE   = 'L',
	S_PATH_ARCTO  = 'A',
	S_PATH_CLOSE  = 'z',

//	S_ATT_ID          = 'id',
	S_ATT_PATH        = 'd',
	S_ATT_FILL        = 'fill',
	S_ATT_STROKE      = 'stroke',
	S_ATT_STROKEWIDTH = 'stroke-width',
	S_ATT_RENDERING   = 'shape-rendering',

	S_NONE = 'none',

	S_ANCHOR = { left:'start', center:'middle', right:'end'},
	S_HEIGHT;

var UA = navigator.userAgent;
if(UA.match(/Chrome/)){
	S_HEIGHT = { 'candle-top':-0.52, top:-0.58, hanging:-0.45, middle:-0.25, alphabetic:0, bottom:0.08 };
}
else if(UA.match(/AppleWebKit/)){
	S_HEIGHT = { 'candle-top':-0.6,  top:-0.82, hanging:-0.82, middle:-0.25, alphabetic:0, bottom:0.18 };
}
else if(UA.match(/Trident/)){
	S_HEIGHT = { 'candle-top':-0.5,  top:-0.72, hanging:-0.72, middle:-0.25, alphabetic:0, bottom:0.25 };
}
else /* if(UA.match(/Gecko/)) */{
	if(UA.match(/Win/)){
		S_HEIGHT = { 'candle-top':-0.65, top:-0.8,  hanging:-0.8,  middle:-0.3,  alphabetic:0, bottom:0.2  };
	}
	else{
		S_HEIGHT = { 'candle-top':-0.5,  top:-0.6,  hanging:-0.6,  middle:-0.25, alphabetic:0, bottom:0.08 };
	}
}

/* ----------------- */
/*   SVG用ラッパー   */
/* ----------------- */
Candle.addTypes('svg');

Candle.addWrapper('svg:vector',{

	initialize : function(parent){
		this.use = new Candle.TypeList('svg');

		// define const
		this.PATH_MOVE  = S_PATH_MOVE;
		this.PATH_LINE  = S_PATH_LINE;
		this.PATH_CLOSE = S_PATH_CLOSE;
		this.PATH_ARCTO = S_PATH_ARCTO;

		Candle.wrapper.vector.prototype.initialize.call(this, parent);
	},

	/* additional functions (for initialize) */
	initElement : function(){
		var rect = Candle.getRectSize(this.canvas);
		var root = this.child = _doc.createElementNS(SVGNS,'svg');
		root.setAttribute('xmlns', SVGNS);
		root.setAttribute('xmlns:xlink', XLINKNS);
		root.setAttribute('id', this.canvasid);
		root.setAttribute('font-size', "10px");
		root.setAttribute('font-family', "sans-serif");
		root.setAttribute('width', rect.width);
		root.setAttribute('height', rect.height);
		root.setAttribute('viewBox', [0,0,rect.width,rect.height].join(' '));
		this.canvas.appendChild(root);
	},
	initFunction : function(){
		function getOuterHTML(el){ return el.outerHTML || new XMLSerializer().serializeToString(el);}
		
		var root = this.child;
		this.canvas.toDataURL = function(type){
			return "data:image/svg+xml;base64," + window.btoa(getOuterHTML(root));
		};
		this.canvas.toBlob = function(f, type){
			var blob = new Blob([getOuterHTML(root)], {type:'image/svg+xml'});
			if(!!f){ f(blob);}
			return blob;
		};
	},

	clear : function(){
		var root = this.canvas.firstChild, el = root.firstChild;
		while(!!el){ root.removeChild(el); el = root.firstChild;}

		this.resetElement();
	},

	/* layer functions */
	setLayerEdge : function(){ /* nop */ },
	createLayer : function(lid){
		var layer = newEL('g');
		layer.setAttribute('id', lid);
		this.child.appendChild(layer);
		return layer;
	},

	/* property functions */
	setRendering : function(render){
		this.target.setAttribute(S_ATT_RENDERING, render);
	},

	changeChildSize : function(child,width,height){
		child.setAttribute('width', width);
		child.setAttribute('height', height);
		var m = child.getAttribute('viewBox').split(/ /);
		child.setAttribute('viewBox', [m[0],m[1],width,height].join(' '));
	},

	/* Canvas API functions (for transform) */
	translate : function(left,top){
		var m = this.child.getAttribute('viewBox').split(/ /);
		m[0]=-left; m[1]=-top;
		this.child.setAttribute('viewBox', m.join(' '));
	},

	/* extended functions */
	setDashSize : function(obj, sizes){
		obj.setAttribute('stroke-dasharray', sizes.join(" "));
	},

	/* SVG Special functions */
	getDefsElement : function(){
		// defs要素がなかったら作成する
		var defs = document.querySelector('defs');
		if(!defs){
			defs = document.createElementNS(SVGNS, 'defs');
			this.child.insertBefore(defs, (this.child.firstChild || null));
		}
		return defs;
	},
	getImageElement : function(image){
		/* defsにimage要素がある場合はそれを参照する */
		var defs = this.getDefsElement();
		var imgel = null, imgs = defs.querySelectorAll("image");
		for(var i=0;i<imgs.length;i++){
			if(imgs[i].getAttributeNS(XLINKNS, "href")===image.src){ imgel = imgs[i]; break;}
		}
		/* defsにimage要素がない場合はdefsにimage要素を追加して返す */
		if(!imgel){
			imgel = newEL('image');
			imgel.setAttribute('id', [this.canvasid, "img", imgs.length].join('_'));
			imgel.setAttribute("width",  image.width);
			imgel.setAttribute("height", image.height);
			imgel.setAttributeNS(XLINKNS, "xlink:href", image.src);
			
			defs.appendChild(imgel);
		}
		return imgel;
	},
	getImageSymbol : function(image,sx,sy,sw,sh){
		/* defsにimage・viewBoxが共通のsymbol要素がある場合はそれを参照する */
		var defs = this.getDefsElement();
		var viewbox = [sx,sy,sw,sh].join(" ");
		var symbol = null, syms = defs.querySelectorAll("symbol");
		for(var i=0;i<syms.length;i++){
			if(syms[i].getAttribute("viewBox")===viewbox){ symbol = syms[i]; break;}
		}
		/* defsにimage・viewBoxが共通のsymbol要素がない場合はdefsにsymbol要素を追加して返す */
		if(!symbol){
			symbol = document.createElementNS(SVGNS, 'symbol');
			symbol.setAttribute("id", [this.canvasid, "symimg", syms.length].join('_'));
			symbol.setAttribute("viewBox", viewbox);
			
			var use = document.createElementNS(SVGNS, 'use');
			use.setAttributeNS(XLINKNS, "xlink:href", "#"+this.getImageElement(image).getAttribute("id"));
			symbol.appendChild(use);
			
			defs.appendChild(symbol);
		}
		return symbol;
	},

	/* Canvas API functions (for text) */
	fillText_main : function(el,text,x,y){
		var newel = !el, _cache = (!!this.vid ? this._textcache[this.vid] || {} : {});
		if(newel){ el = newEL('text');}
		else{ this.show(el);}

		if(el.getAttribute(S_ATT_FILL)!==this.fillStyle){ el.setAttribute(S_ATT_FILL, this.fillStyle);}

		if(_cache.x!==x || _cache.y!==y || _cache.ta!==this.textAlign || _cache.tb!==this.textBaseline || _cache.font!==this.font){
			var ME = Candle.ME;
			ME.style.font = this.font;
			ME.innerHTML = text;
			var top = y - ME.offsetHeight * S_HEIGHT[this.textBaseline.toLowerCase()];
			var anchor = S_ANCHOR[this.textAlign.toLowerCase()];
			 
			if(el.getAttribute('x')!==x)  { el.setAttribute('x', x);}
			if(el.getAttribute('y')!==top){ el.setAttribute('y', top);}
			if(el.getAttribute('text-anchor')!==anchor){ el.setAttribute('text-anchor', anchor);}
			
			_cache.x = x;
			_cache.y = y;
			_cache.ta = this.textAlign;
			_cache.tb = this.textBaseline;
		}

		if(_cache.font!==this.font){
			if(this.font.match(/(.+\s)?([0-9]+)px (.+)$/)){
				var style = RegExp.$1, size = RegExp.$2, family = RegExp.$3;
				el.setAttribute('font-size', size);
				
				if(!family.match(/^sans\-serif$/i)){ el.setAttribute('font-family', family);}
				else{ el.removeAttribute('font-family');}
				
				if(style.match(/(italic|oblique)/)){ el.setAttribute('font-style', RegExp.$1);}
				else{ el.removeAttribute('font-style');}
				
				if(style.match(/(bold|bolder|lighter|[1-9]00)/)){ el.setAttribute('font-weight', RegExp.$1);}
				else{ el.removeAttribute('font-weight');}
			}
			else{
				el.setAttribute('font', this.font);
			}
			
			_cache.font = this.font;
		}

		if(el.textContent!==text){ el.textContent = text;}

		if(!!this.vid){ this._textcache[this.vid] = _cache;}

		if(newel){ this.target.appendChild(el);}
		return el;
	},

	/* Canvas API functions (for image) */
	drawImage_main : function(el,image,sx,sy,sw,sh,dx,dy,dw,dh){
		var newel = !el;
		if(newel){ el = newEL('use');}
		else{ this.show(el);}
		var refid = this.getImageSymbol(image,sx,sy,sw,sh).getAttribute("id");

		/* viewBoxはgetImageSymbol()で設定済み */
		if(el.getAttribute('x')!==dx){ el.setAttribute('x', dx);}
		if(el.getAttribute('y')!==dy){ el.setAttribute('y', dy);}
		if(el.getAttribute('width') !==dw){ el.setAttribute('width',  dw);}
		if(el.getAttribute('height')!==dh){ el.setAttribute('height', dh);}
		if(el.getAttributeNS(XLINKNS, "xlink:href")!=="#"+refid){
			el.setAttributeNS(XLINKNS, "xlink:href", "#"+refid);
		}

		if(newel){ this.target.appendChild(el);}
		return el;
	},

	/* internal functions */
	addVectorElement_main : function(el,isfill,isstroke){
		var newel = !el;
		if(newel){
			el = newEL('path');
			el.setAttribute(S_ATT_FILL,   S_NONE);
			el.setAttribute(S_ATT_STROKE, S_NONE);
		}
		else{ this.show(el);}

		if(!this.freezepath || newel){
			var path = this.cpath.join(' ');
			var linewidth = (isstroke ? this.lineWidth : null);
			if(el.getAttribute(S_ATT_PATH)       !==path)     { el.setAttribute(S_ATT_PATH, path);}
			if(el.getAttribute(S_ATT_STROKEWIDTH)!==linewidth){ el.setAttribute(S_ATT_STROKEWIDTH, linewidth);}
		}
		
		var fillcolor   = (isfill   ? this.fillStyle   : S_NONE);
		var strokecolor = (isstroke ? this.strokeStyle : S_NONE);
		if(el.getAttribute(S_ATT_FILL)  !==fillcolor)  { el.setAttribute(S_ATT_FILL,   fillcolor);}
		if(el.getAttribute(S_ATT_STROKE)!==strokecolor){ el.setAttribute(S_ATT_STROKE, strokecolor);}

		if(newel){ this.target.appendChild(el);}
		return el;
	}
});

})();

// candle.canvas.js
/* global Candle:false, _doc:false, _2PI:false */
 
(function(){

/* ---------------------- */
/*   canvas描画可能条件   */
/* ---------------------- */
if(!document.createElement('canvas').getContext){ return;}

/* -------------------------- */
/*   canvasブラウザ依存対策   */
/* -------------------------- */
if(window.CanvasRenderingContext2D){
	var p = CanvasRenderingContext2D.prototype;
	if(!p.setLineDash){
		if     ('mozDash' in p)       { p.setLineDash = function(sizes){ this.mozDash=sizes;};}
		else if('webkitLineDash' in p){ p.setLineDash = function(sizes){ this.webkitLineDash=sizes;};}
	}
}

var CTOP_OFFSET = 0, UA = navigator.userAgent;
if(UA.match(/Chrome|Trident/)){
	CTOP_OFFSET = -0.5;
}
else if(UA.match(/AppleWebKit/)){
	CTOP_OFFSET = -0.6;
}
else /* if(UA.match(/Gecko/)) */{
	if(UA.match(/Win/)){
		CTOP_OFFSET = -0.65;
	}
	else{
		CTOP_OFFSET = -0.5;
	}
}

/* -------------------- */
/*   Canvas用ラッパー   */
/* -------------------- */
Candle.addTypes('canvas');

Candle.addWrapper('canvas:wrapperbase',{

	initialize : function(parent){
		// variables for internal
		this.context  = null;	// 本来のCanvasRenderingContext2Dオブジェクト

		this.use = new Candle.TypeList('canvas');

		this.x0 = 0;
		this.y0 = 0;

		Candle.wrapper.wrapperbase.prototype.initialize.call(this, parent);
	},
	setkey : function(vid){ return this;},
	hidekey : function(vid){ return this;},
	release : function(vid){ return this;},

	/* extend functions (initialize) */
	initElement : function(){
		var rect = Candle.getRectSize(this.canvas);
		var root = this.child = _doc.createElement('canvas');
		root.id = this.canvasid;
		root.width  = rect.width;
		root.height = rect.height;
		root.style.width  = rect.width + 'px';
		root.style.height = rect.height + 'px';
		this.canvas.appendChild(root);

		this.context = root.getContext('2d');
	},
	initFunction : function(){
		var root = this.child;
		this.canvas.toDataURL = function(type){
			return root.toDataURL(type || void 0);
		};
		this.canvas.toBlob = function(f, type){
			try{ return root.toBlob(f, type);}catch(e){}
			/* Webkit, BlinkにtoBlobがない... */
			root.toDataURL(type || void 0).match(/data:(.*);base64,(.*)/);
			var bin = window.atob(RegExp.$2), len=bin.length;
			var buf = new Uint8Array(len);
			for(var i=0;i<len;i++){ buf[i]=bin.charCodeAt(i);}
			var blob = new Blob([buf.buffer], {type:RegExp.$1});
			if(!!f){ f(blob);}
			return blob;
		};
		root.toBlob = root.toBlob || root.msToBlob;
	},

	clear : function(){
		this.setProperties(true,true);
		this.context.setTransform(1,0,0,1,0,0); // 変形をリセット
		this.context.translate(this.x0, this.y0);
		var rect = Candle.getRectSize(this.canvas);
		this.context.clearRect(0,0,rect.width,rect.height);
	},

	/* layer functions */
	setEdgeStyle : function(){
		var s = this.canvas.style;
		if('imageRendering' in s){
			s.imageRendering = '';
			if(this.isedge){
				s.imageRendering = 'pixelated';
				if(!s.imageRendering){ s.imageRendering = '-webkit-optimize-contrast';}
				if(!s.imageRendering){ s.imageRendering = '-moz-crisp-edges';}
				if(!s.imageRendering){ s.imageRendering = '-o-crisp-edges';}
			}
		}
	},

	/* property functions */
	changeSize : function(width,height){
		var parent = this.canvas;
		parent.style.width  = width + 'px';
		parent.style.height = height + 'px';

		var child = this.child;
		var left = parseInt(child.style.left), top = parseInt(child.style.top); // jshint ignore:line
		width += (left<0?-left:0);
		height += (top<0?-top:0);
		child.style.width  = width + 'px';
		child.style.height = height + 'px';
		child.width  = width;
		child.height = height;
	},

	/* 内部用関数 */
	setProperties : function(isfill,isstroke){
		isfill   = isfill   && !!this.fillStyle   && (this.fillStyle  !=="none");
		isstroke = isstroke && !!this.strokeStyle && (this.strokeStyle!=="none");
		var c = this.context;
		if(isfill)  { c.fillStyle   = this.fillStyle;}
		if(isstroke){ c.strokeStyle = this.strokeStyle;}
		c.lineWidth    = this.lineWidth;
		c.font         = this.font;
		c.textAlign    = this.textAlign;
		c.textBaseline = this.textBaseline;
		return (isfill || isstroke);
	},

	/* Canvas API functions (for path) */
	beginPath : function(){ this.context.beginPath();},
	closePath : function(){ this.context.closePath();},

	moveTo : function(x,y){
		this.context.moveTo(x,y);
	},
	lineTo : function(x,y){
		this.context.lineTo(x,y);
	},
	rect : function(x,y,w,h){
		this.context.rect(x,y,w,h);
	},
	arc  : function(cx,cy,r,startRad,endRad,antiClockWise){
		this.context.arc(cx,cy,r,startRad,endRad,antiClockWise);
	},

	/* Canvas API functions (for drawing) */
	fill : function(){
		if(this.setProperties(true,false)){
			this.context.fill();
		}
	},
	stroke : function(){
		if(this.setProperties(false,true)){
			this.context.stroke();
		}
	},
	shape : function(){
		if(this.setProperties(true,true)){
			var c = this.context;
			if(!!this.fillStyle   && this.fillStyle  !=="none"){ c.fill();}
			if(!!this.strokeStyle && this.strokeStyle!=="none"){ c.stroke();}
		}
	},

	/* Canvas API functions (rect) */
	fillRect   : function(x,y,w,h){
		if(this.setProperties(true,false)){
			this.context.fillRect(x,y,w,h);
		}
	},
	strokeRect : function(x,y,w,h){
		if(this.setProperties(false,true)){
			this.context.strokeRect(x,y,w,h);
		}
	},
	shapeRect : function(x,y,w,h){
		if(this.setProperties(true,true)){
			var c = this.context;
			if(!!this.fillStyle   && this.fillStyle  !=="none"){ c.fillRect(x,y,w,h);}
			if(!!this.strokeStyle && this.strokeStyle!=="none"){ c.strokeRect(x,y,w,h);}
		}
	},

	/* Canvas API functions (for text) */
	fillText : function(text,x,y){
		if(!!text && this.setProperties(true,false)){
			if(this.textBaseline==="candle-top"){
				var ME = Candle.ME;
				ME.style.font = this.font;
				ME.innerHTML = text;
				y -= ME.offsetHeight*CTOP_OFFSET;
				this.context.textBaseline = "alphabetic";
			}
			this.context.fillText(text,x,y);
		}
	},

	/* Canvas API functions (for image) */
	drawImage : function(){
		if(!arguments[0]){ return;}
		this.context.drawImage.apply(this.context, arguments);
	},

	/* Canvas API functions (for transform) */
	translate : function(left,top){
		this.x0 = left;
		this.y0 = top;
		this.context.translate(left, top);
	},

	/* extended functions */
	setLinePath : function(){
		var _args=arguments, _len=_args.length, len=_len-((_len|1)?1:2), a=[];
		for(var i=0;i<len;i+=2){ a[i>>1] = [_args[i],_args[i+1]];}
		this.context.beginPath();
		this.setLinePath_com.call(this,a);
		if(_args[_len-1]){ this.context.closePath();}
	},
	setOffsetLinePath : function(){
		var _args=arguments, _len=_args.length, len=_len-((_len|1)?1:2)-2, a=[];
		for(var i=0;i<len;i+=2){ a[i>>1] = [_args[i+2]+_args[0], _args[i+3]+_args[1]];}
		this.context.beginPath();
		this.setLinePath_com.call(this,a);
		if(_args[_len-1]){ this.context.closePath();}
	},
	setLinePath_com : function(array){
		for(var i=0,len=array.length;i<len;i++){
			var ar=array[i];
			if(i===0){ this.context.moveTo(ar[0],ar[1]);}
			else     { this.context.lineTo(ar[0],ar[1]);}
		}
	},
	setDashSize : function(obj, size){ },

	strokeLine : function(x1,y1,x2,y2){
		if(this.setProperties(false,true)){
			var c = this.context;
			c.beginPath();
			c.moveTo(x1,y1);
			c.lineTo(x2,y2);
			c.stroke();
		}
	},
	strokeDashedLine : function(x1,y1,x2,y2,sizes){
		this.strokeDashedLine = ((!!this.context.setLineDash) ?
			function(x1,y1,x2,y2,sizes){
				var c = this.context;
				if(this.setProperties(false,true)){
					c.beginPath();
					c.moveTo(x1,y1);
					c.lineTo(x2,y2);
					c.setLineDash(sizes);
					c.stroke();
					c.setLineDash([]);
				}
			}
		:
			function(x1,y1,x2,y2,sizes){
				if((sizes.length%2)===1){ sizes = sizes.concat(sizes);}
				var length = Math.sqrt((x2-x1)*(x2-x1)+(y2-y1)*(y2-y1));
				var distance=0, phase=0, tilt=null, tilts=null;
				if(x1!==x2){
					tilt  = (y2-y1)/(x2-x1);
					tilts = tilt*tilt+1;
				}
				
				if(this.setProperties(false,true)){
					var c = this.context;
					c.beginPath();
					c.moveTo(x1, y1);
					while(distance<length){
						var px, py;
						if(tilt!==null){
							var a = Math.sqrt(distance*distance/tilts);
							px = x1+a;
							py = y1+tilt*a;
						}
						else{
							px = x1;
							py = y1+distance;
						}
						if((phase&1)===0){ c.moveTo(px, py);}
						else             { c.lineTo(px, py);}
						distance += sizes[phase];
						phase++;
						if(phase>=sizes.length){ phase=0;}
					}
					c.stroke();
				}
			}
		);
		this.strokeDashedLine(x1,y1,x2,y2,sizes);
	},
	strokeCross : function(cx,cy,l){
		if(this.setProperties(false,true)){
			var c = this.context;
			c.beginPath();
			c.moveTo(cx-l,cy-l);
			c.lineTo(cx+l,cy+l);
			c.moveTo(cx-l,cy+l);
			c.lineTo(cx+l,cy-l);
			c.stroke();
		}
	},

	/* extended functions (circle) */
	fillCircle : function(cx,cy,r){
		if(this.setProperties(true,false)){
			var c = this.context;
			c.beginPath();
			c.arc(cx,cy,r,0,_2PI,false);
			c.fill();
		}
	},
	strokeCircle : function(cx,cy,r){
		if(this.setProperties(false,true)){
			var c = this.context;
			c.beginPath();
			c.arc(cx,cy,r,0,_2PI,false);
			c.stroke();
		}
	},
	shapeCircle : function(cx,cy,r){
		if(this.setProperties(true,true)){
			var c = this.context;
			c.beginPath();
			c.arc(cx,cy,r,0,_2PI,false);
			if(!!this.fillStyle   && this.fillStyle  !=="none"){ c.fill();}
			if(!!this.strokeStyle && this.strokeStyle!=="none"){ c.stroke();}
		}
	}
});

})();

// candle.vml.js
/* global Candle:false, _doc:false, _2PI:false */
 
(function(){

/* ------------------- */
/*   VML描画可能条件   */
/* ------------------- */
try{ document.namespaces.add("v", "urn:schemas-microsoft-com:vml");}catch(e){ return;}

/* ------------------------------------------- */
/*   VectorContext(VML)クラス用const文字列集   */
/* ------------------------------------------- */
var V_TAG_SHAPE    = '<v:shape',
	V_TAG_GROUP    = '<v:group',
	V_TAG_IMAGE    = '<v:image',
	V_TAG_TEXTPATH = '<v:textpath',
	V_TAG_POLYLINE = '<v:polyline',
	V_TAG_PATH_FOR_TEXTPATH = '<v:path textpathok="t" />',
	V_EL_UNSELECTABLE = ' unselectable="on"',
	V_TAGEND      = '>',
	V_TAGEND_NULL = ' />',
//	V_CLOSETAG_SHAPE    = '</v:shape>',
	V_CLOSETAG_GROUP    = '</v:group>',
//	V_CLOSETAG_IMAGE    = '</v:image>',
//	V_CLOSETAG_TEXTPATH = '</v:textpath>',
	V_CLOSETAG_POLYLINE = '</v:polyline>',

//	V_ATT_ID     = ' id="',
//	V_ATT_PATH   = ' path="',
	V_ATT_POINTS = ' points="',
	V_ATT_STYLE  = ' style="',
	V_ATT_STRING = ' string="',
	V_ATT_COORDSIZE    = ' coordsize="100,100"',
	V_ATT_FILLCOLOR    = ' fillcolor="',
//	V_ATT_STROKECOLOR  = ' strokecolor="',
//	V_ATT_STROKEWEIGHT = ' strokeweight="',
	V_ATT_END = '"',
//	V_ATT_STYLE_TEXTBOX = ' style="white-space:nowrap;cursor:default;font:10px sans-serif;"',
	V_DEF_ATT_POLYLINE  = ' stroked="f" filled="t"',
	V_DEF_ATT_TEXTPATH  = ' on="t" xscale="t"',

//	V_STYLE_LEFT  = 'left:',
//	V_STYLE_TOP   = 'top:',
	V_STYLE_FONT  = 'font:',
	V_STYLE_ALIGN = 'v-text-align:',
	V_STYLE_END   = ';',

	V_PATH_MOVE   = 'm',
	V_PATH_LINE   = 'l',
	V_PATH_CLOSE  = 'x',
	V_PATH_ARCTO  = '?', /* 'at'か'wa'どちらか */
	V_PATH_NOSTROKE = 'ns',
	V_PATH_NOFILL   = 'nf',

	V_WIDTH = { left:0, center:0.5, right:1 },
	V_HEIGHT = { 'candle-top':-0.25, top:-0.4, hanging:-0.4, middle:0, alphabetic:0.22, bottom:0.4 },

	Z  = 10,
	Z2 = Z/2;

function ePos(num){
	num += (num>0?0.5:-0.5);
	return (num*Z-Z2)|0;
}
function eLen(num){
	return (num*Z)|0;
}

var Super = Candle.wrapper.vector.prototype;

/* ----------------------- */
/*   CSS, NameSpace設定    */
/* ----------------------- */
/* addNameSpace for VML */
/* ネームスペースの追加はVML描画可能条件に移動しました */

/* addStyleSheet for VML */
var V_BH  = "behavior: url(#default#VML);";
var V_BH2 = V_BH + " position:absolute; width:10px; height:10px;";
Candle.addCSS("v\\:shape",    V_BH2);
Candle.addCSS("v\\:group",    V_BH2);
Candle.addCSS("v\\:polyline", V_BH2);
Candle.addCSS("v\\:image",    V_BH2);
Candle.addCSS("v\\:path",     V_BH);
Candle.addCSS("v\\:textpath", V_BH);
Candle.addCSS("v\\:stroke",   V_BH);

/* ----------------------- */
/*   VectorContextクラス   */
/* ----------------------- */
Candle.addTypes('vml');

Candle.addWrapper('vml:vector',{

	initialize : function(parent){
		this.use = new Candle.TypeList('vml');

		// define const
		this.PATH_MOVE  = V_PATH_MOVE;
		this.PATH_LINE  = V_PATH_LINE;
		this.PATH_CLOSE = V_PATH_CLOSE;
		this.PATH_ARCTO = V_PATH_ARCTO;

		Super.initialize.call(this, parent);
	},

	/* additional functions (for initialize) */
	setParent : function(){
		var parent = this.canvas;
		parent.style.overflow = 'hidden';
		parent.style.display  = 'block';
		parent.style.position = 'relative';
		return parent;
	},
	initElement : function(){
		var rect = Candle.getRectSize(this.canvas);
		var root = this.child = _doc.createElement('div');
		root.id = this.canvasid;
		root.style.position = 'absolute';
		root.style.left   = '-2px';
		root.style.top    = '-2px';
		root.style.width  = rect.width + 'px';
		root.style.height = rect.height + 'px';
		this.canvas.appendChild(root);
	},

	/* layer functions */
	createLayer : function(lid){
		var layer = _doc.createElement('div');
		layer.id = lid;
		layer.unselectable = 'on';
		layer.style.position = 'absolute';
		layer.style.left   = '0px';
		layer.style.top    = '0px';
		this.child.appendChild(layer);
		return layer;
	},

	/* property functions */
	changeChildSize : function(child,width,height){
		child.style.width  = width + 'px';
		child.style.height = height + 'px';
	},

	/* Canvas API functions (for transform) */
	translate : function(left,top){
		var child = this.canvas.firstChild;
		child.style.position = 'absolute';
		child.style.left = left+'px';
		child.style.top  = top +'px';
	},

	/* Canvas API functions (for path) */
	moveTo : function(x,y){
		this.cpath.push(this.PATH_MOVE,ePos(x),ePos(y));
		this.lastpath = this.PATH_MOVE;
	},
	lineTo : function(x,y){
		if(this.lastpath!==this.PATH_LINE){ this.cpath.push(this.PATH_LINE);}
		this.cpath.push(ePos(x),ePos(y));
		this.lastpath = this.PATH_LINE;
	},
	rect : function(x,y,w,h){
		x=ePos(x); y=ePos(y); w=eLen(w); h=eLen(h);
		this.cpath.push(this.PATH_MOVE,x,y,this.PATH_LINE,(x+w),y,(x+w),(y+h),x,(y+h),this.PATH_CLOSE);
		this.lastpath = this.PATH_CLOSE;
	},
	arc : function(cx,cy,r,startRad,endRad,antiClockWise){
		var sx,sy,ex,ey;
		if(endRad-startRad>=_2PI){ sx=cx+r; sy=cy; ex=cx+r; ey=cy;}
		else{
			sx = cx + r*Math.cos(startRad); sy = cy + r*Math.sin(startRad);
			ex = cx + r*Math.cos(endRad);   ey = cy + r*Math.sin(endRad);
		}
		if(endRad-startRad>=_2PI){ sy+=0.125;}
		var com = (antiClockWise ? 'at' : 'wa');
		this.cpath.push(com,ePos(cx-r),ePos(cy-r),ePos(cx+r),ePos(cy+r),ePos(sx),ePos(sy),ePos(ex),ePos(ey));
		this.lastpath = com;
	},

	/* extended functions */
	setLinePath_com : function(array){
		for(var i=0,len=array.length;i<len;i++){
			this.cpath.push(i===0 ? this.PATH_MOVE : this.PATH_LINE);
			this.cpath.push(ePos(array[i][0]),ePos(array[i][1]));
		}
	},
	setDashSize : function(obj, sizes){
		var el = _doc.createElement('v:stroke');
		if     (sizes[0]<=2){ el.dashstyle = 'ShortDash';}
		else if(sizes[0]<=5){ el.dashstyle = 'Dash';}
		else                { el.dashstyle = 'LongDash';}
		obj.appendChild(el);
	},

	strokeLine : function(x1,y1,x2,y2){
		Super.strokeLine.call(this,ePos(x1),ePos(y1),ePos(x2),ePos(y2));
	},
	strokeDashedLine : function(x1,y1,x2,y2,sizes){
		Super.strokeDashedLine.call(this,ePos(x1),ePos(y1),ePos(x2),ePos(y2),sizes);
	},
	strokeCross : function(cx,cy,l){
		Super.strokeCross.call(this,ePos(cx),ePos(cy),eLen(l));
	},

	/* Canvas API functions (for text) */
	fillText_main : function(el,text,x,y){
		var newel = !el, _cache = (!!this.vid ? this._textcache[this.vid] || {} : {});
		var fillcolor = Candle.parse(this.fillStyle);

		if(!newel && (_cache.x!==x || _cache.y!==y || _cache.ta!==this.textAlign || _cache.tb!==this.textBaseline || _cache.font!==this.font)){
			this.target.removeChild(el);
			newel = true;
		}

		if(newel){
			var ME = Candle.ME;
			ME.style.font = this.font;
			ME.innerHTML = text;
			var wid = (ME.offsetWidth*Z-Z2)|0;
			var left = ((x - ME.offsetWidth  * V_WIDTH [this.textAlign.toLowerCase()]   )*Z-Z2)|0;
			var top  = ((y - ME.offsetHeight * V_HEIGHT[this.textBaseline.toLowerCase()])*Z-Z2)|0;
			
			var ar = [
				V_TAG_GROUP, V_EL_UNSELECTABLE, V_ATT_COORDSIZE, V_TAGEND,
					V_TAG_POLYLINE, V_ATT_POINTS, [left,top,left+wid,top].join(','), V_ATT_END,
					V_DEF_ATT_POLYLINE, V_ATT_FILLCOLOR, fillcolor, V_ATT_END, V_TAGEND,
						V_TAG_PATH_FOR_TEXTPATH,
						
						V_TAG_TEXTPATH, V_DEF_ATT_TEXTPATH, V_ATT_STRING, text, V_ATT_END,
						V_ATT_STYLE, V_STYLE_FONT, this.font, V_STYLE_END,
						V_STYLE_ALIGN, this.textAlign, V_STYLE_END, V_ATT_END, V_TAGEND_NULL,
					V_CLOSETAG_POLYLINE,
				V_CLOSETAG_GROUP
			];
			this.target.insertAdjacentHTML('BeforeEnd', ar.join(''));
			el = this.target.lastChild;
			
			if(!!this.vid){
				this._textcache[this.vid] = { x:x, y:y, font:this.font, ta:this.textAlign, tb:this.textBaseline };
				this.elements[this.vid] = el;
			}
		}
		else{
			this.show(el);
			if(""+el.lastChild.fillcolor !== fillcolor){ el.lastChild.fillcolor = fillcolor;}
			if(el.lastChild.lastChild.string!==text){ el.lastChild.lastChild.string = text;}
		}

		return el;
	},

	/* Canvas API functions (for image) */
	drawImage_main : function(el,image,sx,sy,sw,sh,dx,dy,dw,dh){
		var newel = !el;
		if(newel){
			var ar = [V_TAG_IMAGE, V_EL_UNSELECTABLE, V_ATT_COORDSIZE, V_TAGEND_NULL];
			this.target.insertAdjacentHTML('BeforeEnd', ar.join(''));
			el = this.target.lastChild;
		}
		else{ this.show(el);}

		el.src = image.src;
		el.style.left = dx;
		el.style.top  = dy;
		el.style.width  = dw;
		el.style.height = dh;
		el.style.display = 'inline';
		el.cropleft = sx/image.width;
		el.croptop  = sy/image.height;
		el.cropright  = (1-(sx+sw)/image.width);
		el.cropbottom = (1-(sy+sh)/image.height);

		return el;
	},

	/* internal functions */
	addVectorElement_main : function(el,isfill,isstroke){
		var newel = !el;
		if(newel){
			var ar = [V_TAG_SHAPE, V_EL_UNSELECTABLE, V_ATT_COORDSIZE, V_TAGEND_NULL];
			this.target.insertAdjacentHTML('BeforeEnd', ar.join(''));
			el = this.target.lastChild;
		}
		else{ this.show(el);}

		if(!this.freezepath || newel){
			var path = [this.cpath.join(' '), (!isfill ? V_PATH_NOFILL : ''), (!isstroke ? V_PATH_NOSTROKE : '')].join('');
			var linewidth = ''+this.lineWidth+'px';
			if(newel || ""+el.path !== path){ el.path = path;}
			if(isstroke && ""+el.strokeweight !== linewidth){ el.strokeweight = linewidth;}
		}
		
		var fillcolor   = (isfill   ? Candle.parse(this.fillStyle)   : "none");
		var strokecolor = (isstroke ? Candle.parse(this.strokeStyle) : "none");
		if(""+el.fillcolor   !== fillcolor)  { el.fillcolor   = fillcolor;}
		if(""+el.strokecolor !== strokecolor){ el.strokecolor = strokecolor;}

		return el;
	},

	/* VectorID Functions */
	show : function(el){ el.style.display = 'inline';},
	hide : function(el){ el.style.display = 'none';}
});

})();

// outro.js

})();
